#pragma once

/*
	GameEngine and Editor
	by John Ryland
	Copyright (c) 2023
*/

////////////////////////////////////////////////////////////////////////////////////
//	NkWindow

#include "Nk.h"
#include <GLFW/glfw3.h>

namespace GameEngine {

class NkWindow
{
public:
    NkWindow();
    ~NkWindow();

    void GetSizes(int& width, int& height, int& display_width, int& display_height);
    bool Update();
    void Present();
    struct nk_context* Context();

private:
    struct nk_context ctx;
    GLFWwindow *win;
};

} // GameEngine namespace
